DALF3 model
===========
 
Four-field model for electron pressure, vorticity, A|| and parallel
velocity

References:
- B.Scott, Plasma Phys. Contr. Fusion 39 (1997) 1635
- B.Scott, "Drift Wave versus Interchange Turbulence in Tokamak
  Geometry: Linear versus Nonlinear Mode Structure"
  arXiv:physics/0207126 Feb 2001

NOTE: The normalisation used here is different to in the above
papers. See manual in doc/ subdirectory for details
